\name{oasis}
\alias{oasis}
 \title{OASIS for one variable}

 \description{Compute Outlier And Subgroup Identification Statistics for One Variable}

\usage{
oasis (x, s0 = 0, unitize = TRUE, method = "all") 
}
 \arguments{
 \item{x}{a vector of input data values}
 \item{s0}{a constant added to the scale estimate prior to computing the t-statistic. Default is zero.}
 \item{unitize}{If TRUE, x will be shifted and scaled so that its values fall in (0,1) if they don't already.}
 \item{method}{specify which method to use: "mast" = maximum spacing, "mist"  most informative spacing, "dip" - dip test, "lms.mop" - least median squares with minimum outlier p-value, "lms.sst" - least median squares with sum of squared t-statistics, "loo.mop" - leave-one-out with minimum outlier p-value or "loo.sst" - leave-one-out with sum of squared t-statistics. Default is set to "all".}}

 \value{a vector with some or all of the following entries, depending on the method(s) chosen:
  \item{mast.a}{value of observation that defines the left endpoint of the maximum spacing}
  \item{mast.b}{value of observation that defines the right endpoint of the maximum spacing}
  \item{mast.stat}{maximum spacing statistic (MAST), the largest first difference of sorted data values.}
  \item{p.mast}{p-value for mast statistic}
  \item{mast.index}{index of the maximum spacing}
  \item{mast.hi}{number of data points located to the right of the maximum spacing}
  \item{mist.a}{value of observation that defines the left endpoint of the most informative spacing}
  \item{mist.b}{value of observation that defines the right endpoint of the most informative spacing}
  \item{mist.stat}{most informative spacing test (MIST) statistic}
  \item{mist.index}{index of most informative spacing}
  \item{mist.hi}{number of data points located to the right of the most informative spacing}
  \item{lms.bulk}{narrowest interval covering half the data}
  \item{lms.bulk.index}{indices of sorted data values for the narrowest interval covering half the data}
  \item{lms.bulk.size}{width of narrowests interval covering half the data}
  \item{lms.center}{least median square (LMS) estimate of center = mean of observations in the narrowest interval covering half the data}
  \item{lms.scale}{LMS scale estimate obtained by matching narrowest interval covering half the data to middle 50\% of the normal distribution}
  \item{lms.maxt}{maximum outlier t-statistic by LMS}
  \item{lms.mop.stat}{minimum outlier p-value by LMS}
  \item{lms.sst.stat}{sum of squared outlier t-statistics by LMS}
  \item{dip.stat}{the dip statisticof Hartigan and Hartigan}
  \item{loo.maxt}{maximum outlier t-statistic by leave-one-out (LOO)}
  \item{loo.maxt.index}{index of maximum absolute outlier t-statistic}
  \item{loo.mop.stat}{minimum outlier p-value by LOO}
  \item{loo.sst.stat}{sum of squared outlier t-statistics by LOO}}
 
 \details{See \code{\link{full.oasis}} for a detailed description of the result statistics.}

 \examples{
 u=runif(50)
 u.res=oasis(u)
 z=rnorm(50)
 z.res=oasis(z,unitize=TRUE)
 b=rbeta(50,0.2,0.2)
 b.res=oasis(b)
 }
 \author{Stan Pounds \email{stanley.pounds@stjude.org}}
