\name{oasis.sim}
\alias{oasis.sim}
 \title{Simulation statistics for OASIS}

 \description{Calculate simulations statistics for all OASIS methods}

\usage{
oasis.sim (nsim = 10000, nsubj, s0 = 0, method = "all") 
}
 \arguments{
  \item{nsim}{number of simulations, default is 10000.}
  \item{nsubj}{number of subjects}
  \item{s0}{a constant added to the scale estimate prior to computing the t-statistic. Default is zero.} 
  \item{method}{specify which method to use: "mast" = maximum spacing, "mist"  most informative spacing, "dip" - dip test, "lms.mop" - least median squares with minimum outlier p-value, "lms.sst" - least median squares with sum of squared t-statistics, "loo.mop" - leave-one-out with minimum outlier p-value or "loo.sst" - leave-one-out with sum of squared t-statistics. Default is set to "all".}}

 \value{a data frame with the following columns (in the case method="all"):
 \item{mast.stat.usim}{MAST statistic for a data set simulated from the uniform(0,1) distribution.}
 \item{mist.stat.usim}{MIST statistic for a data set simulated from the uniform(0,1) distribution.}
 \item{lms.mop.usim}{least median squares minimum outlier p-value for a data set simulated from the uniform(0,1) distribution.}
 \item{lms.sst.usim}{least median squares sum of squared t-statistics for a data set simulated from the uniform(0,1) distribution.}
 \item{dip.stat.usim}{the dip statistic for a data set simulated from the uniform(0,1) distribution}
 \item{loo.mop.usim}{the leave-one-out minimum outlier p-value for a data set simulated from the uniform(0,1) distribution.}
 \item{loo.sst.usim}{the leave-one-out sum of squared t-statistics for a data set simulated from the uniform(0,1) distribution.}
 \item{mast.stat.zsim}{MAST statistic for a data set simulated from the normal(0,1) distribution.}
 \item{mist.stat.zsim}{MIST statistic for a data set simulated from the normal(0,1) distribution.}
 \item{lms.mop.stat.zsim}{least median squares minimum outlier p-value for a data set simulated from the normal(0,1) distribution.}
 \item{lms.sst.stat.zsim}{least median squares sum of squared t-statistics for a data set simulated from the normal(0,1) distribution.}
 \item{dip.stat.zsim}{the dip statistic for a data set simulated from the normal(0,1) distribution}
 \item{loo.mop.stat.zsim}{the leave-one-out minimum outlier p-value for a data set simulated from the normal(0,1) distribution.}
 \item{loo.sst.stat.zsim}{the leave-one-out sum of squared t-statistics for a data set simulated from the normal(0,1) distribution.}
 See \code{\link{full.oasis}} for more description of theses statistics.  All the "usim" results on the
 same row are results for the same simulated uniform(0,1) data set and all the "zsim" results on the
 same row are the results for the same simulated normal(0,1) data set.}
 
 \examples{
 sim.res=oasis.sim(nsim=1000,nsubj=50)
 head(sim.res)}
 \author{Stan Pounds \email{stanley.pounds@stjude.org}}
