\name{one.oasis.plot}
\alias{one.oasis.plot}

 \title{Plotting OASIS results}

 \description{Plots data values and confidence intervals for all OASIS methods for a vector of data values}

\usage{
one.oasis.plot (x, s0 = 0, unitize = FALSE, alpha = 0.01, nsim = ceiling(10/alpha), 
    sim.stats = NULL, ...) 
}
 \arguments{
 \item{x}{a vector of pqt transformed data values}
 \item{s0}{a constant added to the scale estimate prior to computing the t-statistic for LMS and LOO. Default is 1/(2*nrow(data.set)).}
 \item{unitize}{logical, whether to unitize x. Default is NULL.}
 \item{alpha}{significance level for confidence intervals}
 \item{nsim}{number of simulations for calculating p-values. Default is 10000.}
 \item{sim.stats}{list with two matrices with simulated statistics for uniform and normal distributions, default is null, so the function will calculate the simulated values.}
 \item{...}{other graphical options for \code{plot}, such as \code{main}, etc.}}

 \value{NULL}
  \author{Stan Pounds \email{stanley.pounds@stjude.org}}

 \examples{
 u=runif(50)
 one.oasis.plot(u)
 z=rnorm(50)
 one.oasis.plot(z,unitize=TRUE)
 
 # make a plot of an exon of the GLIS2 gene that was
 # found to have bimodal distribution (cf. Gruber et al. 2012)
 data.columns=5:18
 # perform positive quantile transformation of specified columns of data
 pqt.data=pq.transform(M7example,data.columns,add.row.id=TRUE)
 glis2=grep("GLIS2",pqt.data$gene)
 x=pqt.data[glis2[8],data.columns+1] # since the first column is added (row.id)
 one.oasis.plot(as.numeric(x))}
