\name{row.oasis}
\alias{row.oasis}
 \title{OASIS for each row of a data matrix}

 \description{Calculate Outlier And Subgroup Identification Statistics for each row of a data set}

\usage{
row.oasis (data.set, data.columns = 1:ncol(data.set), s0 = 1/(2 * 
    (nrow(data.set))), unitize = FALSE, method = "all", sim.stats = NULL, 
    nsim = 10000) 
}
 \arguments{
  \item{data.set}{a matrix or data.frame.}
  \item{data.columns}{columns of data.set to perform OASIS: the index of the columns or the names of the columns.  Default is to include all columns.}
  \item{s0}{a constant added to the scale estimate prior to computing the t-statistic. Default is 1/(2*(nrow(data.set))).}
  \item{unitize}{logical, whether to unitize each row of the data.set by separate shift-and-scale transformation. Default is set to FALSE.}
  \item{method}{specify which method to use: "mast" = maximum spacing, "mist"  most informative spacing, "dip" - dip test, "lms.mop" - least median squares with minimum outlier p-value, "lms.sst" - least median squares with sum of squared t-statistics, "loo.mop" - leave-one-out with minimum outlier p-value or "loo.sst" - leave-one-out with sum of squared t-statistics. Default is set to "all".}
  \item{sim.stats}{a data.frame with simulated statistics for uniform and normal distributions or NULL. Default is NULL, so the function will calculate simulated statistics.}
  \item{nsim}{number of simulations for calculating simulated statistics. Default is 10000.}}

 \value{An object with the similar structure as the results of \link{full.oasis} but includes only the results for the methods indicated by the value of the \code{method} argument.}

 \references{1.Pawlikowska I., Wu G., Edmonson M., Liu Z., Gruber T., Zhang J., Pounds S. (2014) \emph{Bioinformatics}, in print. \cr
             2. Pyke R. (1965) Spacings. \emph{J. R. Statist. Soc. B} (27): 395-449. \cr
             3. Rousseeuw P. J. (1984) Least Median of Squares Regression.  \emph{ Journal of the American Statistical Association} (79): 871-880. \cr
             4. Hartigan JA and Hartigan PM (1985) The Dip Test of Unimodality, \emph{Annals of Statistics} 13: 70-84. \cr
             5. Nord A. S., Lee M., King M.-C., Walsh T. (2011) Accurate and exact CNV identification from targeted high-throughput sequence data.  \emph{BMC Genomics} 12, 184.}

 \author{Stan Pounds \email{stanley.pounds@stjude.org}}

  \examples{
  # load data
  data(M7example)
  # specify columns of data to transform
  data.columns=5:18

  # perform positive quantile transformation of specified columns of data
  pqt.data=pq.transform(M7example,data.columns,add.row.id=TRUE)
  # add.row.id=TRUE so there is an additional column with row identifiers
  data.columns=data.columns+1  # since there is an additional column row.id
 
  # define s0
  s0=1/(2*(nrow(M7example)))
  # perform OASIS and calculate values of simulations statistics
  res=row.oasis(pqt.data,data.columns,s0=s0,sim.stats=NULL,nsim=1000)
  names(res)
  head(res$oasis.res)
  head(res$sim.stats)
 
  # or we can insert values of simulations statistics
  res.new=row.oasis(pqt.data,s0=s0,data.columns,sim.stats=res$sim.stats) 
  
  # we can specify a particular method we are interested in, i.e MIST
  res.new=row.oasis(pqt.data,s0=s0,data.columns,sim.stats=res$sim.stats,method="mist")
  colnames(res.new$oasis.res) }  
